==> estateplat-common-1.2.4-20190704.111009-192-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSdmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zx@gtmap.cn">zx</a>
 * @version 1.0, 2018-9-30
 * @description 不动产登记水电煤信息
 */
@Table(name = "BDC_SDMXX")
public class BdcSdmxx {
    @Id
    private String sdmxxid; //水电煤信息ID
    private String xmid;//项目id
    private String skhh;//水卡户号
    private String dkhh;//电卡户号
    private String rqkhh;//燃气卡户号
    private String dskh;//电视卡号
    private String sfghswk;//是否过户水务卡
    private String sfghrqk;//是否过户燃气卡
    private String sfghdsk;//是否过户电视卡
    private String sfghdfk;//是否过户电费卡

    public String getSdmxxid() {
        return sdmxxid;
    }

    public void setSdmxxid(String sdmxxid) {
        this.sdmxxid = sdmxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSkhh() {
        return skhh;
    }

    public void setSkhh(String skhh) {
        this.skhh = skhh;
    }

    public String getDkhh() {
        return dkhh;
    }

    public void setDkhh(String dkhh) {
        this.dkhh = dkhh;
    }

    public String getRqkhh() {
        return rqkhh;
    }

    public void setRqkhh(String rqkhh) {
        this.rqkhh = rqkhh;
    }

    public String getSfghswk() {
        return sfghswk;
    }

    public void setSfghswk(String sfghswk) {
        this.sfghswk = sfghswk;
    }

    public String getSfghrqk() {
        return sfghrqk;
    }

    public void setSfghrqk(String sfghrqk) {
        this.sfghrqk = sfghrqk;
    }

    public String getSfghdsk() {
        return sfghdsk;
    }

    public void setSfghdsk(String sfghdsk) {
        this.sfghdsk = sfghdsk;
    }

    public String getDskh() {
        return dskh;
    }

    public void setDskh(String dskh) {
        this.dskh = dskh;
    }

    public String getSfghdfk() {
        return sfghdfk;
    }

    public void setSfghdfk(String sfghdfk) {
        this.sfghdfk = sfghdfk;
    }
}

==> estateplat-common-1.2.4-20210924.064033-892-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSdmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zx@gtmap.cn">zx</a>
 * @version 1.0, 2018-9-30
 * @description 不动产登记水电煤信息
 */
@Table(name = "BDC_SDMXX")
public class BdcSdmxx {
    @Id
    private String sdmxxid; //水电煤信息ID
    private String xmid;//项目id
    private String skhh;//水卡户号
    private String dkhh;//电卡户号
    private String rqkhh;//燃气卡户号
    private String dskh;//电视卡号
    private String sfghswk;//是否过户水务卡
    private String sfghrqk;//是否过户燃气卡
    private String sfghdsk;//是否过户电视卡
    private String sfghdfk;//是否过户电费卡
    private String sffsjf;//是否分时缴费
    private String yhzdkgxsfjb;//原户主代扣关系是否解绑
    private String sfsfdw;//水费收费单位
    private String dfsfdw;//电费收费单位
    private String rqsfdw;//燃气收费单位
    private String dssfdw;//广电卡收费单位(电视收费)

    public String getSffsjf() {
        return sffsjf;
    }

    public void setSffsjf(String sffsjf) {
        this.sffsjf = sffsjf;
    }

    public String getYhzdkgxsfjb() {
        return yhzdkgxsfjb;
    }

    public void setYhzdkgxsfjb(String yhzdkgxsfjb) {
        this.yhzdkgxsfjb = yhzdkgxsfjb;
    }

    public String getSfsfdw() {
        return sfsfdw;
    }

    public void setSfsfdw(String sfsfdw) {
        this.sfsfdw = sfsfdw;
    }

    public String getDfsfdw() {
        return dfsfdw;
    }

    public void setDfsfdw(String dfsfdw) {
        this.dfsfdw = dfsfdw;
    }

    public String getRqsfdw() {
        return rqsfdw;
    }

    public void setRqsfdw(String rqsfdw) {
        this.rqsfdw = rqsfdw;
    }

    public String getDssfdw() {
        return dssfdw;
    }

    public void setDssfdw(String dssfdw) {
        this.dssfdw = dssfdw;
    }

    public String getSdmxxid() {
        return sdmxxid;
    }

    public void setSdmxxid(String sdmxxid) {
        this.sdmxxid = sdmxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSkhh() {
        return skhh;
    }

    public void setSkhh(String skhh) {
        this.skhh = skhh;
    }

    public String getDkhh() {
        return dkhh;
    }

    public void setDkhh(String dkhh) {
        this.dkhh = dkhh;
    }

    public String getRqkhh() {
        return rqkhh;
    }

    public void setRqkhh(String rqkhh) {
        this.rqkhh = rqkhh;
    }

    public String getSfghswk() {
        return sfghswk;
    }

    public void setSfghswk(String sfghswk) {
        this.sfghswk = sfghswk;
    }

    public String getSfghrqk() {
        return sfghrqk;
    }

    public void setSfghrqk(String sfghrqk) {
        this.sfghrqk = sfghrqk;
    }

    public String getSfghdsk() {
        return sfghdsk;
    }

    public void setSfghdsk(String sfghdsk) {
        this.sfghdsk = sfghdsk;
    }

    public String getDskh() {
        return dskh;
    }

    public void setDskh(String dskh) {
        this.dskh = dskh;
    }

    public String getSfghdfk() {
        return sfghdfk;
    }

    public void setSfghdfk(String sfghdfk) {
        this.sfghdfk = sfghdfk;
    }
}
